@@ -24,6 +24,7 @@
 #include "appearance-font.h"
 #include "appearance-themes.h"
 #include "appearance-style.h"
+#include "appearance-support.h"
 #include "theme-installer.h"
 #include "theme-thumbnail.h"
 #include "activate-settings-daemon.h"
@@ -60,7 +61,15 @@ init_appearance_data (int *argc, char ***argv, GOptionContext *context)
   else
     {
       data = g_new (AppearanceData, 1);
-      data->client = mateconf_client_get_default ();
+      data->settings = g_settings_new (APPEARANCE_SCHEMA);
+      data->wp_settings = g_settings_new (WP_SCHEMA);
+      data->caja_settings = g_settings_new (CAJA_SCHEMA);
+      data->interface_settings = g_settings_new (INTERFACE_SCHEMA);
+      data->marco_settings = g_settings_new (MARCO_SCHEMA);
+      data->mouse_settings = g_settings_new (MOUSE_SCHEMA);
+#ifdef HAVE_XFT2
+      data->font_settings = g_settings_new (FONT_RENDER_SCHEMA);
+#endif /* HAVE_XFT2 */
       data->ui = ui;
       data->thumb_factory = mate_desktop_thumbnail_factory_new (MATE_DESKTOP_THUMBNAIL_SIZE_NORMAL);
     }
@@ -82,9 +91,18 @@ main_window_response (GtkWidget *widget,
     style_shutdown (data);
     desktop_shutdown (data);
     font_shutdown (data);
+    support_shutdown (data);
 
     g_object_unref (data->thumb_factory);
-    g_object_unref (data->client);
+    g_object_unref (data->settings);
+    g_object_unref (data->wp_settings);
+    g_object_unref (data->caja_settings);
+    g_object_unref (data->interface_settings);
+    g_object_unref (data->marco_settings);
+    g_object_unref (data->mouse_settings);
+#ifdef HAVE_XFT2
+    g_object_unref (data->font_settings);
+#endif /* HAVE_XFT2 */
     g_object_unref (data->ui);
   }
   else if (response_id == GTK_RESPONSE_HELP)
@@ -167,6 +185,9 @@ main (int argc, char **argv)
   g_strfreev (wallpaper_files);
   font_init (data);
 
+  /* init support for other window managers */
+  support_init (data);
+
   /* prepare the main window */
   w = appearance_capplet_get_widget (data, "appearance_window");
   capplet_set_icon (w, "preferences-desktop-theme");
