@@ -1,11 +1,12 @@
 #ifndef WM_COMMON_H
 #define WM_COMMON_H
 
-#define WM_COMMON_MARCO    "Marco"
-#define WM_COMMON_SAWFISH  "Sawfish"
-#define WM_COMMON_METACITY "Metacity"
-#define WM_COMMON_COMPIZ   "compiz"
-#define WM_COMMON_UNKNOWN  "Unknown"
+#define WM_COMMON_MARCO       "Marco"
+#define WM_COMMON_SAWFISH     "Sawfish"
+#define WM_COMMON_METACITY    "Metacity"
+#define WM_COMMON_COMPIZ      "Compiz"
+#define WM_COMMON_COMPIZ_OLD  "compiz"
+#define WM_COMMON_UNKNOWN     "Unknown"
 
 gchar *wm_common_get_current_window_manager (void);
 /* Returns a strv of keybinding names for the window manager;
