@@ -44,11 +44,11 @@
 
 #define TILE_EXEC_NAME "Tile_desktop_exec_name"
 #define SECONDS_IN_DAY 86400
-#define EXIT_SHELL_ON_ACTION_START "exit_shell_on_action_start"
-#define EXIT_SHELL_ON_ACTION_HELP "exit_shell_on_action_help"
-#define EXIT_SHELL_ON_ACTION_ADD_REMOVE "exit_shell_on_action_add_remove"
-#define EXIT_SHELL_ON_ACTION_UPGRADE_UNINSTALL "exit_shell_on_action_upgrade_uninstall"
-#define NEW_APPS_FILE_KEY "new_apps_file_key"
+#define CC_SCHEMA "org.mate.control-center"
+#define EXIT_SHELL_ON_ACTION_START "cc-exit-shell-on-action-start"
+#define EXIT_SHELL_ON_ACTION_HELP "cc-exit-shell-on-action-help"
+#define EXIT_SHELL_ON_ACTION_ADD_REMOVE "cc-exit-shell-on-action-add-remove"
+#define EXIT_SHELL_ON_ACTION_UPGRADE_UNINSTALL "cc-exit-shell-on-action-upgrade-uninstall"
 
 static void create_application_category_sections (AppShellData * app_data);
 static GtkWidget *create_filter_section (AppShellData * app_data, const gchar * title);
@@ -842,17 +842,20 @@ matemenu_tree_changed_callback (MateMenuTree * old_tree, gpointer user_data)
 }
 
 AppShellData *
-appshelldata_new (const gchar * menu_name, NewAppConfig * new_apps, const gchar * mateconf_keys_prefix,
-	GtkIconSize icon_size, gboolean show_tile_generic_name, gboolean exit_on_close)
+appshelldata_new (const gchar * menu_name, GtkIconSize icon_size, gboolean show_tile_generic_name, gboolean exit_on_close, gint new_apps_max_items)
 {
 	AppShellData *app_data = g_new0 (AppShellData, 1);
-	app_data->mateconf_prefix = mateconf_keys_prefix;
-	app_data->new_apps = new_apps;
+	app_data->settings = g_settings_new (CC_SCHEMA);
 	app_data->menu_name = menu_name;
 	app_data->icon_size = icon_size;
 	app_data->stop_incremental_relayout = TRUE;
 	app_data->show_tile_generic_name = show_tile_generic_name;
 	app_data->exit_on_close = exit_on_close;
+	if (new_apps_max_items > 0) {
+		app_data->new_apps = g_new0 (NewAppConfig, 1);
+		app_data->new_apps->max_items = new_apps_max_items;
+		app_data->new_apps->name = _("New Applications");
+	}
 	return app_data;
 }
 
@@ -955,8 +958,8 @@ generate_category (const char * category, MateMenuTreeDirectory * root_dir, AppS
 static gboolean
 check_specific_apps_hack (MateDesktopItem * item)
 {
-	static const gchar *COMMAND_LINE_LOCKDOWN_MATECONF_KEY =
-		"/desktop/mate/lockdown/disable_command_line";
+	static const gchar *COMMAND_LINE_LOCKDOWN_SCHEMA = "org.mate.lockdown";
+	static const gchar *COMMAND_LINE_LOCKDOWN_KEY = "disable-command-line";
 	static const gchar *COMMAND_LINE_LOCKDOWN_DESKTOP_CATEGORY = "TerminalEmulator";
 	static gboolean got_lockdown_value = FALSE;
 	static gboolean command_line_lockdown;
@@ -967,7 +970,10 @@ check_specific_apps_hack (MateDesktopItem * item)
 	if (!got_lockdown_value)
 	{
 		got_lockdown_value = TRUE;
-		command_line_lockdown = get_slab_mateconf_bool (COMMAND_LINE_LOCKDOWN_MATECONF_KEY);
+		GSettings *lockdown_settings;
+		lockdown_settings = g_settings_new (COMMAND_LINE_LOCKDOWN_SCHEMA);
+		command_line_lockdown = g_settings_get_boolean (lockdown_settings, COMMAND_LINE_LOCKDOWN_KEY);
+		g_object_unref (lockdown_settings);
 	}
 
 	/* This seems like an ugly hack but it's the way it's currently done in the old control center */
@@ -1064,9 +1070,7 @@ generate_new_apps (AppShellData * app_data)
 	gchar *all_apps;
 	GError *error = NULL;
 	gchar *separator = "\n";
-	gchar *mateconf_key;
 
-	gchar *basename;
 	gchar *all_apps_file_name;
 	gchar **all_apps_split;
 	gint x;
@@ -1075,17 +1079,7 @@ generate_new_apps (AppShellData * app_data)
 	GList *categories, *launchers;
 	GHashTable *new_apps_dups;
 
-	mateconf_key = g_strdup_printf ("%s%s", app_data->mateconf_prefix, NEW_APPS_FILE_KEY);
-	basename = get_slab_mateconf_string (mateconf_key);
-	g_free (mateconf_key);
-	if (!basename)
-	{
-		g_warning ("Failure getting mateconf key NEW_APPS_FILE_KEY");
-		return;
-	}
-
-	all_apps_file_name = g_build_filename (g_get_home_dir (), basename, NULL);
-	g_free (basename);
+	all_apps_file_name = g_build_filename (g_get_user_config_dir (), "mate", "ab-newapps.txt", NULL);
 
 	if (!g_file_get_contents (all_apps_file_name, &all_apps, NULL, &error))
 	{
@@ -1251,7 +1245,7 @@ insert_launcher_into_category (CategoryData * cat_data, MateDesktopItem * deskto
 
 	launcher =
 		application_tile_new_full (mate_desktop_item_get_location (desktop_item),
-		app_data->icon_size, app_data->show_tile_generic_name, app_data->mateconf_prefix);
+		app_data->icon_size, app_data->show_tile_generic_name);
 	gtk_widget_set_size_request (launcher, SIZING_TILE_WIDTH, -1);
 
 	filepath =
@@ -1350,19 +1344,16 @@ static void
 handle_launcher_single_clicked (Tile * launcher, gpointer data)
 {
 	AppShellData *app_data = (AppShellData *) data;
-	gchar *mateconf_key;
 
 	tile_trigger_action (launcher, launcher->actions[APPLICATION_TILE_ACTION_START]);
 
-	mateconf_key = g_strdup_printf ("%s%s", app_data->mateconf_prefix, EXIT_SHELL_ON_ACTION_START);
-	if (get_slab_mateconf_bool (mateconf_key))
+	if (g_settings_get_boolean (app_data->settings, EXIT_SHELL_ON_ACTION_START))
 	{
 		if (app_data->exit_on_close)
 			gtk_main_quit ();
 		else
 			hide_shell (app_data);
 	}
-	g_free (mateconf_key);
 }
 
 static void
@@ -1375,38 +1366,35 @@ handle_menu_action_performed (Tile * launcher, TileEvent * event, TileAction * a
 	temp = NULL;
 	if (action == launcher->actions[APPLICATION_TILE_ACTION_START])
 	{
-		temp = g_strdup_printf ("%s%s", app_data->mateconf_prefix, EXIT_SHELL_ON_ACTION_START);
+		temp = EXIT_SHELL_ON_ACTION_START;
 	}
 
 	else if (action == launcher->actions[APPLICATION_TILE_ACTION_HELP])
 	{
-		temp = g_strdup_printf ("%s%s", app_data->mateconf_prefix, EXIT_SHELL_ON_ACTION_HELP);
+		temp = EXIT_SHELL_ON_ACTION_HELP;
 	}
 
 	else if (action == launcher->actions[APPLICATION_TILE_ACTION_UPDATE_MAIN_MENU]
 		|| action == launcher->actions[APPLICATION_TILE_ACTION_UPDATE_STARTUP])
 	{
-		temp = g_strdup_printf ("%s%s", app_data->mateconf_prefix,
-			EXIT_SHELL_ON_ACTION_ADD_REMOVE);
+		temp = EXIT_SHELL_ON_ACTION_ADD_REMOVE;
 	}
 
 	else if (action == launcher->actions[APPLICATION_TILE_ACTION_UPGRADE_PACKAGE]
 		|| action == launcher->actions[APPLICATION_TILE_ACTION_UNINSTALL_PACKAGE])
 	{
-		temp = g_strdup_printf ("%s%s", app_data->mateconf_prefix,
-			EXIT_SHELL_ON_ACTION_UPGRADE_UNINSTALL);
+		temp = EXIT_SHELL_ON_ACTION_UPGRADE_UNINSTALL;
 	}
 
 	if (temp)
 	{
-		if (get_slab_mateconf_bool (temp))
+		if (g_settings_get_boolean (app_data->settings, temp))
 		{
 			if (app_data->exit_on_close)
 				gtk_main_quit ();
 			else
 				hide_shell (app_data);
 		}
-		g_free (temp);
 	}
 	else
 		g_warning ("Unknown Action");
