@@ -30,10 +30,13 @@
 #include "libslab-utils.h"
 #include "bookmark-agent.h"
 
-#define MATECONF_SEND_TO_CMD_KEY       "/desktop/mate/applications/main-menu/file-area/file_send_to_cmd"
-#define MATECONF_ENABLE_DELETE_KEY_DIR "/apps/caja/preferences"
-#define MATECONF_ENABLE_DELETE_KEY     MATECONF_ENABLE_DELETE_KEY_DIR "/enable_delete"
-#define MATECONF_CONFIRM_DELETE_KEY    MATECONF_ENABLE_DELETE_KEY_DIR "/confirm_trash"
+#define GNOME_MAIN_MENU_SCHEMA         "org.mate.gnome-main-menu.file-area"
+#define SETTINGS_FILE_MGR_OPEN_KEY     "file-mgr-open-cmd"
+#define SETTINGS_SEND_TO_CMD_KEY       "file-send-to-cmd"
+
+#define CAJA_SCHEMA                    "org.mate.caja.preferences"
+#define SETTINGS_ENABLE_DELETE_KEY     "enable-delete"
+#define SETTINGS_CONFIRM_DELETE_KEY    "confirm-trash"
 
 G_DEFINE_TYPE (DocumentTile, document_tile, NAMEPLATE_TILE_TYPE)
 
@@ -64,7 +67,7 @@ static void send_to_trigger              (Tile *, TileEvent *, TileAction *);
 static void rename_entry_activate_cb (GtkEntry *, gpointer);
 static gboolean rename_entry_key_release_cb (GtkWidget *, GdkEventKey *, gpointer);
 
-static void mateconf_enable_delete_cb (MateConfClient *, guint, MateConfEntry *, gpointer);
+static void settings_enable_delete_cb (GSettings *, gchar *, gpointer);
 
 static void agent_notify_cb (GObject *, GParamSpec *, gpointer);
 
@@ -82,7 +85,9 @@ typedef struct
 	gchar * force_icon_name;  //show an icon instead of a thumbnail
 
 	gboolean delete_enabled;
-	guint mateconf_conn_id;
+
+	GSettings *caja_settings;
+	GSettings *gnome_main_menu_settings;
 
 	BookmarkAgent       *agent;
 	BookmarkStoreStatus  store_status;
@@ -340,7 +345,6 @@ document_tile_private_setup (DocumentTile *this)
 	GFile *file;
 	GAppInfo *app;
 
-	MateConfClient *client;
 	GError *error = NULL;
 
 	file = g_file_new_for_uri (TILE (this)->uri);
@@ -351,16 +355,13 @@ document_tile_private_setup (DocumentTile *this)
 		g_error_free (error);
 	g_object_unref (file);
 
-	priv->delete_enabled =
-		(gboolean) GPOINTER_TO_INT (get_mateconf_value (MATECONF_ENABLE_DELETE_KEY));
+	priv->gnome_main_menu_settings = g_settings_new (GNOME_MAIN_MENU_SCHEMA);
+	priv->caja_settings = g_settings_new (CAJA_SCHEMA);
 
-	client = mateconf_client_get_default ();
+	priv->delete_enabled = g_settings_get_boolean (priv->caja_settings, SETTINGS_ENABLE_DELETE_KEY);
 
-	mateconf_client_add_dir (client, MATECONF_ENABLE_DELETE_KEY_DIR, MATECONF_CLIENT_PRELOAD_NONE, NULL);
-	priv->mateconf_conn_id =
-		connect_mateconf_notify (MATECONF_ENABLE_DELETE_KEY, mateconf_enable_delete_cb, this);
-
-	g_object_unref (client);
+	g_signal_connect (priv->caja_settings, "changed::" SETTINGS_ENABLE_DELETE_KEY,
+		G_CALLBACK (settings_enable_delete_cb), this);
 
 	priv->notify_signal_id = g_signal_connect (
 		G_OBJECT (priv->agent), "notify", G_CALLBACK (agent_notify_cb), this);
@@ -383,7 +384,9 @@ document_tile_init (DocumentTile *tile)
 	priv->force_icon_name  = NULL;
 
 	priv->delete_enabled   = FALSE;
-	priv->mateconf_conn_id    = 0;
+
+	priv->caja_settings            = NULL;
+	priv->gnome_main_menu_settings = NULL;
 
 	priv->agent            = NULL;
 	priv->store_status     = BOOKMARK_STORE_DEFAULT;
@@ -396,8 +399,6 @@ document_tile_finalize (GObject *g_object)
 {
 	DocumentTilePrivate *priv = DOCUMENT_TILE_GET_PRIVATE (g_object);
 
-	MateConfClient *client;
-
 	g_free (priv->basename);
 	g_free (priv->mime_type);
 	g_free (priv->force_icon_name);
@@ -410,12 +411,8 @@ document_tile_finalize (GObject *g_object)
 
 	g_object_unref (G_OBJECT (priv->agent));
 
-	client = mateconf_client_get_default ();
-
-	mateconf_client_notify_remove (client, priv->mateconf_conn_id);
-	mateconf_client_remove_dir (client, MATECONF_ENABLE_DELETE_KEY_DIR, NULL);
-
-	g_object_unref (client);
+	g_object_unref (priv->gnome_main_menu_settings);
+	g_object_unref (priv->caja_settings);
 
 	G_OBJECT_CLASS (document_tile_parent_class)->finalize (g_object);
 }
@@ -829,7 +826,7 @@ rename_entry_key_release_cb (GtkWidget *widget, GdkEventKey *event, gpointer use
 }
 
 static void
-mateconf_enable_delete_cb (MateConfClient *client, guint conn_id, MateConfEntry *entry, gpointer user_data)
+settings_enable_delete_cb (GSettings *settings, gchar *key, gpointer user_data)
 {
 	Tile *tile = TILE (user_data);
 	DocumentTilePrivate *priv = DOCUMENT_TILE_GET_PRIVATE (user_data);
@@ -842,7 +839,7 @@ mateconf_enable_delete_cb (MateConfClient *client, guint conn_id, MateConfEntry
 
 	menu = GTK_MENU_SHELL (tile->context_menu);
 
-	delete_enabled = mateconf_value_get_bool (entry->value);
+	delete_enabled = g_settings_get_boolean (settings, key);
 
 	if (delete_enabled == priv->delete_enabled)
 		return;
@@ -904,6 +901,7 @@ open_with_default_trigger (Tile *tile, TileEvent *event, TileAction *action)
 static void
 open_in_file_manager_trigger (Tile *tile, TileEvent *event, TileAction *action)
 {
+	DocumentTilePrivate *priv = DOCUMENT_TILE_GET_PRIVATE (tile);
 	GFile *filename;
 	GFile *dirname;
 	gchar *uri;
@@ -918,7 +916,7 @@ open_in_file_manager_trigger (Tile *tile, TileEvent *event, TileAction *action)
 		g_warning ("error getting dirname for [%s]\n", TILE (tile)->uri);
 	else
 	{
-		cmd = string_replace_once (get_slab_mateconf_string (SLAB_FILE_MANAGER_OPEN_CMD),
+		cmd = string_replace_once (g_settings_get_string(priv->gnome_main_menu_settings, SETTINGS_FILE_MGR_OPEN_KEY),
 			"FILE_URI", uri);
 		spawn_process (cmd);
 
@@ -1011,7 +1009,7 @@ delete_trigger (Tile *tile, TileEvent *event, TileAction *action)
 	GError *error = NULL;
 
 
-	if (GPOINTER_TO_INT (libslab_get_mateconf_value (MATECONF_CONFIRM_DELETE_KEY))) {
+	if (g_settings_get_boolean (priv->caja_settings, SETTINGS_CONFIRM_DELETE_KEY)) {
 		confirm_dialog = GTK_DIALOG(gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_WARNING, 
 				GTK_BUTTONS_NONE, _("Are you sure you want to permanently delete \"%s\"?"), priv->basename));
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG(confirm_dialog), _("If you delete an item, it is permanently lost."));
@@ -1074,6 +1072,7 @@ user_docs_trigger (Tile *tile, TileEvent *event, TileAction *action)
 static void
 send_to_trigger (Tile *tile, TileEvent *event, TileAction *action)
 {
+	DocumentTilePrivate *priv = DOCUMENT_TILE_GET_PRIVATE (tile);
 	gchar *cmd;
 	gchar **argv;
 
@@ -1086,7 +1085,7 @@ send_to_trigger (Tile *tile, TileEvent *event, TileAction *action)
 	gchar *tmp;
 	gint i;
 
-	cmd = (gchar *) get_mateconf_value (MATECONF_SEND_TO_CMD_KEY);
+	cmd = g_settings_get_string (priv->gnome_main_menu_settings, SETTINGS_SEND_TO_CMD_KEY);
 	argv = g_strsplit (cmd, " ", 0);
 
 	filename = g_filename_from_uri (TILE (tile)->uri, NULL, NULL);
