@@ -22,7 +22,6 @@
 #define __MATE_UTILS_H__
 
 #include <gtk/gtk.h>
-#include <mateconf/mateconf-client.h>
 #include <libmate/mate-desktop-item.h>
 
 #ifdef __cplusplus
@@ -32,9 +31,6 @@ extern "C" {
 gboolean load_image_by_id (GtkImage * image, GtkIconSize size,
 	const gchar * image_id);
 MateDesktopItem *load_desktop_item_by_unknown_id (const gchar * id);
-gpointer get_mateconf_value (const gchar * key);
-void set_mateconf_value (const gchar * key, gconstpointer data);
-guint connect_mateconf_notify (const gchar * key, MateConfClientNotifyFunc cb, gpointer user_data);
 void handle_g_error (GError ** error, const gchar * user_format, ...);
 GtkWidget *get_main_menu_section_header (const gchar * markup);
 
